@@ -1,6 +1,5 @@
 use crate::{Client, Protocol};
 use futures_util::stream::StreamExt;
-use log::{debug, info};
 use rand::{
     distributions::{Alphanumeric, Distribution},
     thread_rng,
@@ -9,8 +8,9 @@ use shiplift::{
     rep::{ContainerCreateInfo, ContainerDetails},
     ContainerOptions, PullOptions, RmContainerOptions,
 };
-use std::{collections::HashMap, net::SocketAddrV4};
+use std::collections::HashMap;
 
+#[derive(Debug, Clone, Copy)]
 struct Port {
     pub source: u32,
     pub host: u32,
@@ -27,6 +27,7 @@ struct Port {
 /// Container. The Containers will NOT clean themselves up when they are
 /// dropped, you must call the [delete](Container::delete) method on them to
 /// remove the container from the host machine.
+#[derive(Debug, Clone)]
 pub struct Container {
     pub(crate) details: ContainerDetails,
 
@@ -49,7 +50,7 @@ impl Container {
     /// }
     ///  ```
     pub async fn new(image_name: impl Into<String>) -> Result<Container, shiplift::Error> {
-        ContainerBuilder::new(image_name).build().await
+        Builder::new(image_name).build().await
     }
 
     /// Pull an image and create a new Docker container from it.
@@ -70,15 +71,12 @@ impl Container {
     /// }
     ///  ```
     pub async fn pull(image_name: impl Into<String>) -> Result<Container, shiplift::Error> {
-        ContainerBuilder::new(image_name)
-            .pull_on_build(true)
-            .build()
-            .await
+        Builder::new(image_name).pull_on_build().build().await
     }
 
     /// Create a new Docker container with advanced configuration.
     ///
-    /// Check the [ContainerBuilder](ContainerBuilder) documentation for the
+    /// Check the [Builder](Builder) documentation for the
     /// full list of options.
     ///
     /// # Example
@@ -102,9 +100,9 @@ impl Container {
     ///             // expose ports on the container to the host machine
     ///             .expose(5984, 5984, Protocol::Tcp)
     ///     
-    ///             // if true, pull the image from the webular information
+    ///             // if set, pull the image from the webular information
     ///             // super-highway before building.
-    ///             .pull_on_build(true)
+    ///             .pull_on_build()
     ///     
     ///             // build the container using the above parameters
     ///             .build()
@@ -117,31 +115,21 @@ impl Container {
     ///     println!("container deleted!");
     /// }
     /// ```
-    pub fn builder(image_name: impl Into<String>) -> ContainerBuilder {
-        ContainerBuilder::new(image_name)
+    pub fn builder(image_name: impl Into<String>) -> Builder {
+        Builder::new(image_name)
     }
 
     /// Return the Docker id of the running container
+    #[must_use]
     pub fn id(&self) -> &str {
         &self.details.id
     }
 
-    /// Not yet implemented
-    pub fn ports(&self) -> &HashMap<SourcePort, Vec<HostPort>> {
-        let _map = self
-            .details
-            .network_settings
-            .ports
-            .clone()
-            .unwrap_or_default();
-
-        todo!()
-    }
-
     /// Exposes the underlying representation of the Docker container's ports.
     /// It's messy, this part of the API will change shortly.
-    pub fn ports_raw(&self) -> &Option<HashMap<String, Option<Vec<HashMap<String, String>>>>> {
-        &self.details.network_settings.ports
+    #[must_use]
+    pub fn ports_raw(&self) -> Option<&PortMap> {
+        self.details.network_settings.ports.as_ref()
     }
 
     /// Delete the running docker container.
@@ -156,14 +144,18 @@ impl Container {
     }
 }
 
-pub type SourcePort = (u16, Protocol);
-pub type HostPort = SocketAddrV4;
+pub type PortMap = HashMap<String, Option<Vec<HashMap<String, String>>>>;
+
+// pub type SourcePort = (u16, Protocol);
+// pub type HostPort = SocketAddrV4;
 
 /// Builder struct for fine control over the construction of a
-/// [Container](Container).
+/// [`Container`].
 ///
-/// see [Container::builder()](Container::builder) for example.
-pub struct ContainerBuilder {
+/// see [`Container::builder`] for example.
+#[derive(Debug)]
+#[must_use]
+pub struct Builder {
     image_name: String,
     image_tag: String,
     name: Option<String>,
@@ -177,9 +169,9 @@ pub struct ContainerBuilder {
     slug_length: usize,
 }
 
-impl ContainerBuilder {
+impl Builder {
     fn new(image_name: impl Into<String>) -> Self {
-        ContainerBuilder {
+        Self {
             image_name: image_name.into(),
             image_tag: String::from("latest"),
             name: None,
@@ -204,8 +196,7 @@ impl ContainerBuilder {
         self
     }
 
-    /// Use an alternative Docker [Client](Client) to manipulate the
-    /// Container.ContainerBuilder
+    /// Use an alternative Docker [Client](Client)
     ///
     /// This defaults to a globally shared Docker client at the default socket.
     /// This should be fine in just about all cases.
@@ -279,18 +270,19 @@ impl ContainerBuilder {
 
     /// Set whether the client will attempt to pull the image from the internet
     /// before running the container. defaults to false.
-    pub fn pull_on_build(mut self, pull: bool) -> Self {
-        self.pull_on_build = pull;
+    pub fn pull_on_build(mut self) -> Self {
+        self.pull_on_build = true;
         self
     }
 
-    /// Consume the ContainerBuilder and return a future which resolves to the
+    /// Consume the Builder and return a future which resolves to the
     /// Container (or an error!).
     pub async fn build(self) -> Result<Container, shiplift::Error> {
         let image = self.image();
         let commands = self.commands.iter().map(AsRef::as_ref).collect();
 
         if self.pull_on_build {
+            dbg!("pulling image");
             pull_image(&self.client, &image).await?;
         }
 
@@ -314,17 +306,17 @@ impl ContainerBuilder {
 }
 
 async fn pull_image(client: &Client, image: &str) -> Result<(), shiplift::Error> {
-    info!("pulling image: {}", &image);
+    log::info!("pulling image: {}", &image);
 
     let mut stream = client
         .images()
         .pull(&PullOptions::builder().image(image).build());
     while let Some(Ok(chunk)) = stream.next().await {
         // let chunk = chunk?;
-        debug!("{}", chunk);
+        log::debug!("{}", chunk);
     }
 
-    info!("pulled image: {}", &image);
+    log::info!("pulled image: {}", &image);
     Ok(())
 }
 
