@@ -1,14 +1,14 @@
-#![warn(clippy::all)]
-#![warn(missing_docs)]
+#![deny(clippy::all, missing_docs, missing_debug_implementations)]
+#![warn(clippy::pedantic)]
+#![allow(clippy::missing_errors_doc)]
 
-//! [![Build Status](https://travis-ci.org/danieleades/harbourmaster.svg?branch=master)](https://travis-ci.org/danieleades/harbourmaster)
+//! [![Continuous integration](https://github.com/danieleades/harbourmaster/actions/workflows/CI.yml/badge.svg)](https://github.com/danieleades/harbourmaster/actions/workflows/CI.yml)
 //! [![Latest Docs](https://docs.rs/harbourmaster/badge.svg)](https://docs.rs/harbourmaster/)
 //!
 //! Harbourmaster is a library of high-level abstractions of Docker objects.
 //!
 //! Harbourmaster is built on top of the excellent '[shiplift](https://github.com/softprops/shiplift)', but provides an object-oriented interface that
-//! is a little easier to work with for some use cases. It's also using
-//! async/await-ready futures-0.3 for the interface.
+//! is a little easier to work with for some use cases.
 //!
 //! Particularly useful for unit testing that involves spinning up and then
 //! removing Docker containers.
@@ -38,6 +38,6 @@ mod network;
 pub use crate::network::Network;
 mod port;
 pub use crate::port::Protocol;
-pub use container::{Container, ContainerBuilder};
+pub use container::{Builder as ContainerBuilder, Container};
 
 pub use shiplift::Error;
